@@ -4,6 +4,7 @@
  * Copyright (C) 2017, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2018, Adam Reichold <adam.reichold@t-online.de>
  * Copyright (C) 2019, Masamichi Hosoda <trueroad@trueroad.jp>
+ * Copyright (C) 2019, Oliver Sander <oliver.sander@tu-dresden.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +21,9 @@
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+/**
+ \file poppler-document.h
+ */
 #include "poppler-destination.h"
 #include "poppler-document.h"
 #include "poppler-embedded-file.h"
@@ -55,7 +59,7 @@ initer::initer()
     std::lock_guard<std::mutex> lock{mutex};
 
     if (!count) {
-        globalParams = new GlobalParams(!data_dir.empty() ? data_dir.c_str() : nullptr);
+        globalParams = std::make_unique<GlobalParams>(!data_dir.empty() ? data_dir.c_str() : nullptr);
         setErrorCallback(detail::error_function, nullptr);
     }
     count++;
@@ -68,8 +72,7 @@ initer::~initer()
     if (count > 0) {
         --count;
         if (!count) {
-            delete globalParams;
-            globalParams = nullptr;
+            globalParams.reset();
         }
     }
 }
