@@ -16,7 +16,7 @@
 // Copyright (C) 2006 Takashi Iwai <tiwai@suse.de>
 // Copyright (C) 2007 Koji Otani <sho@bbr.jp>
 // Copyright (C) 2007 Carlos Garcia Campos <carlosgc@gnome.org>
-// Copyright (C) 2008, 2009, 2012, 2014-2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008, 2009, 2012, 2014-2019 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2008 Tomas Are Haavet <tomasare@gmail.com>
 // Copyright (C) 2012 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
 // Copyright (C) 2012, 2017 Adrian Johnson <ajohnson@redneon.com>
@@ -32,9 +32,9 @@
 
 #include <config.h>
 
-#include <stdlib.h>
-#include <string.h>
-#include <limits.h>
+#include <cstdlib>
+#include <cstring>
+#include <climits>
 #include <algorithm>
 #include "goo/gmem.h"
 #include "goo/GooLikely.h"
@@ -572,7 +572,7 @@ void FoFiTrueType::convertToType1(const char *psName, const char **newEncoding,
 }
 
 void FoFiTrueType::convertToCIDType2(const char *psName,
-				     int *cidMap, int nCIDs,
+				     const int *cidMap, int nCIDs,
 				     bool needVerticalMetrics,
 				     FoFiOutputFunc outputFunc,
 				     void *outputStream) const {
@@ -880,7 +880,7 @@ void FoFiTrueType::cvtEncoding(char **encoding,
 }
 
 void FoFiTrueType::cvtCharStrings(char **encoding,
-				  int *codeToGID,
+				  const int *codeToGID,
 				  FoFiOutputFunc outputFunc,
 				  void *outputStream) const {
   const char *name;
