@@ -15,7 +15,7 @@
 //
 // Copyright (C) 2006 Takashi Iwai <tiwai@suse.de>
 // Copyright (C) 2007 Koji Otani <sho@bbr.jp>
-// Copyright (C) 2011, 2012, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2011, 2012, 2018, 2019 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2012 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
 // Copyright (C) 2016 William Bader <williambader@hotmail.com>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
@@ -28,10 +28,9 @@
 #ifndef FOFITRUETYPE_H
 #define FOFITRUETYPE_H
 
-#include "stddef.h"
+#include <cstddef>
 #include <unordered_map>
 #include <string>
-#include "goo/gtypes.h"
 #include "FoFiBase.h"
 
 class GooString;
@@ -51,7 +50,7 @@ public:
   // Create a FoFiTrueType object from a file on disk.
   static FoFiTrueType *load(const char *fileName, int faceIndexA=0);
 
-  ~FoFiTrueType();
+  ~FoFiTrueType() override;
 
   // Returns true if this an OpenType font containing CFF data, false
   // if it's a TrueType font (or OpenType font with TrueType data).
@@ -71,11 +70,11 @@ public:
   int findCmap(int platform, int encoding) const;
 
   // Return the GID corresponding to <c> according to the <i>th cmap.
-  int mapCodeToGID(int i, Guint c) const;
+  int mapCodeToGID(int i, unsigned int c) const;
 
   // map gid to vertical glyph gid if exist.
   //   if not exist return original gid
-  Guint mapToVertGID(Guint orgGID);
+  unsigned int mapToVertGID(unsigned int orgGID);
 
   // Returns the GID corresponding to <name> according to the post
   // table.  Returns 0 if there is no mapping for <name> or if the
@@ -126,7 +125,7 @@ public:
   // name (so we don't need to depend on the 'name' table in the
   // font).  The <cidMap> array maps CIDs to GIDs; it has <nCIDs>
   // entries.  (Not useful for OpenType CFF fonts.)
-  void convertToCIDType2(const char *psName, int *cidMap, int nCIDs,
+  void convertToCIDType2(const char *psName, const int *cidMap, int nCIDs,
 			 bool needVerticalMetrics,
 			 FoFiOutputFunc outputFunc, void *outputStream) const;
 
@@ -170,25 +169,25 @@ private:
 		   FoFiOutputFunc outputFunc,
 		   void *outputStream) const;
   void cvtCharStrings(char **encoding,
-		      int *codeToGID,
+		      const int *codeToGID,
 		      FoFiOutputFunc outputFunc,
 		      void *outputStream) const;
   void cvtSfnts(FoFiOutputFunc outputFunc,
 		void *outputStream, GooString *name,
 		bool needVerticalMetrics,
                 int *maxUsedGlyph) const;
-  void dumpString(const Guchar *s, int length,
+  void dumpString(const unsigned char *s, int length,
 		  FoFiOutputFunc outputFunc,
 		  void *outputStream) const;
-  Guint computeTableChecksum(const Guchar *data, int length) const;
+  unsigned int computeTableChecksum(const unsigned char *data, int length) const;
   void parse();
   void readPostTable();
   int seekTable(const char *tag) const;
-  Guint charToTag(const char *tagName);
-  Guint doMapToVertGID(Guint orgGID);
-  Guint scanLookupList(Guint listIndex, Guint orgGID);
-  Guint scanLookupSubTable(Guint subTable, Guint orgGID);
-  int checkGIDInCoverage(Guint coverage, Guint orgGID);
+  unsigned int charToTag(const char *tagName);
+  unsigned int doMapToVertGID(unsigned int orgGID);
+  unsigned int scanLookupList(unsigned int listIndex, unsigned int orgGID);
+  unsigned int scanLookupSubTable(unsigned int subTable, unsigned int orgGID);
+  int checkGIDInCoverage(unsigned int coverage, unsigned int orgGID);
 
   TrueTypeTable *tables;
   int nTables;
@@ -202,8 +201,8 @@ private:
 
   bool parsedOk;
   int faceIndex;
-  Guint gsubFeatureTable;
-  Guint gsubLookupList;
+  unsigned int gsubFeatureTable;
+  unsigned int gsubLookupList;
 };
 
 #endif
