@@ -33,7 +33,7 @@ public:
 
   PopplerInputStream(GInputStream *inputStream, GCancellable *cancellableA,
                      Goffset startA, bool limitedA, Goffset lengthA, Object &&dictA);
-  ~PopplerInputStream();
+  ~PopplerInputStream() override;
   BaseStream *copy() override;
   Stream *makeSubStream(Goffset start, bool limited,
                         Goffset lengthA, Object &&dictA) override;
