@@ -8,8 +8,8 @@
 
 #include <config.h>
 
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 #include "goo/gmem.h"
 #include "FontEncodingTables.h"
 #include "BuiltinFont.h"
@@ -35,7 +35,7 @@ BuiltinFontWidths::~BuiltinFontWidths() {
   gfree(tab);
 }
 
-bool BuiltinFontWidths::getWidth(const char *name, Gushort *width) {
+bool BuiltinFontWidths::getWidth(const char *name, unsigned short *width) {
   int h;
   BuiltinFontWidth *p;
 
