@@ -34,10 +34,10 @@
 
 #include <set>
 #include <limits>
-#include <stddef.h>
-#include <stdlib.h>
-#include <string.h>
-#include <ctype.h>
+#include <cstddef>
+#include <cstdlib>
+#include <cstring>
+#include <cctype>
 #include "goo/gmem.h"
 #include "goo/GooString.h"
 #include "Error.h"
@@ -185,8 +185,8 @@ bool FormWidget::setAdditionalAction(Annot::FormAdditionalActionsType t, const G
   return widget->setFormAdditionalAction(t, js);
 }
 
-FormWidgetButton::FormWidgetButton (PDFDoc *docA, Object *aobj, unsigned num, Ref refA, FormField *p) :
-	FormWidget(docA, aobj, num, refA, p)
+FormWidgetButton::FormWidgetButton (PDFDoc *docA, Object *dictObj, unsigned num, Ref refA, FormField *p) :
+	FormWidget(docA, dictObj, num, refA, p)
 {
   type = formButton;
   onStr = nullptr;
@@ -264,8 +264,8 @@ FormFieldButton *FormWidgetButton::parent() const
 }
 
 
-FormWidgetText::FormWidgetText (PDFDoc *docA, Object *aobj, unsigned num, Ref refA, FormField *p) :
-	FormWidget(docA, aobj, num, refA, p)
+FormWidgetText::FormWidgetText (PDFDoc *docA, Object *dictObj, unsigned num, Ref refA, FormField *p) :
+	FormWidget(docA, dictObj, num, refA, p)
 {
   type = formText;
 }
@@ -346,8 +346,8 @@ FormFieldText *FormWidgetText::parent() const
   return static_cast<FormFieldText*>(field);
 }
 
-FormWidgetChoice::FormWidgetChoice(PDFDoc *docA, Object *aobj, unsigned num, Ref refA, FormField *p) :
-	FormWidget(docA, aobj, num, refA, p)
+FormWidgetChoice::FormWidgetChoice(PDFDoc *docA, Object *dictObj, unsigned num, Ref refA, FormField *p) :
+	FormWidget(docA, dictObj, num, refA, p)
 {
   type = formChoice;
 }
@@ -458,8 +458,8 @@ FormFieldChoice *FormWidgetChoice::parent() const
   return static_cast<FormFieldChoice*>(field);
 }
 
-FormWidgetSignature::FormWidgetSignature(PDFDoc *docA, Object *aobj, unsigned num, Ref refA, FormField *p) :
-	FormWidget(docA, aobj, num, refA, p)
+FormWidgetSignature::FormWidgetSignature(PDFDoc *docA, Object *dictObj, unsigned num, Ref refA, FormField *p) :
+	FormWidget(docA, dictObj, num, refA, p)
 {
   type = formSignature;
 }
@@ -585,7 +585,7 @@ GooString* FormWidgetSignature::getCheckedSignature(Goffset *checkedFileSize)
             }
             if (sigLen > 0 && 2*(sigLen+lenBytes) <= len-4)
             {
-              for (int i = 2*(sigLen+lenBytes)+4; i < len; ++i)
+              for (Goffset i = 2*(sigLen+lenBytes)+4; i < len; ++i)
               {
                 if (gstr.getChar(i) != '0')
                 {
@@ -598,9 +598,9 @@ GooString* FormWidgetSignature::getCheckedSignature(Goffset *checkedFileSize)
               len = 0;
           }
         }
-        for (int i = 0; i < len; ++i)
+        for ( const char c : gstr.toStr() )
         {
-          if (!isxdigit(gstr.getChar(i)))
+          if (!isxdigit(c))
             len = 0;
         }
         if (len > 0)
@@ -977,8 +977,8 @@ void FormField::setReadOnly (bool value)
 //------------------------------------------------------------------------
 // FormFieldButton
 //------------------------------------------------------------------------
-FormFieldButton::FormFieldButton(PDFDoc *docA, Object &&aobj, const Ref refA, FormField *parentA, std::set<int> *usedParents)
-  : FormField(docA, std::move(aobj), refA, parentA, usedParents, formButton)
+FormFieldButton::FormFieldButton(PDFDoc *docA, Object &&dictObj, const Ref refA, FormField *parentA, std::set<int> *usedParents)
+  : FormField(docA, std::move(dictObj), refA, parentA, usedParents, formButton)
 {
   Dict* dict = obj.getDict();
   active_child = -1;
@@ -1147,8 +1147,8 @@ FormFieldButton::~FormFieldButton()
 //------------------------------------------------------------------------
 // FormFieldText
 //------------------------------------------------------------------------
-FormFieldText::FormFieldText(PDFDoc *docA, Object &&aobj, const Ref refA, FormField *parentA, std::set<int> *usedParents)
-  : FormField(docA, std::move(aobj), refA, parentA, usedParents, formText)
+FormFieldText::FormFieldText(PDFDoc *docA, Object &&dictObj, const Ref refA, FormField *parentA, std::set<int> *usedParents)
+  : FormField(docA, std::move(dictObj), refA, parentA, usedParents, formText)
 {
   Dict* dict = obj.getDict();
   Object obj1;
@@ -1441,7 +1441,12 @@ FormFieldChoice::FormFieldChoice(PDFDoc *docA, Object &&aobj, const Ref refA, Fo
     } else if (obj1.isArray()) {
       for (int i = 0; i < numChoices; i++) {
         for (int j = 0; j < obj1.arrayGetLength(); j++) {
-          Object obj2 = obj1.arrayGet(j);
+          const Object obj2 = obj1.arrayGet(j);
+          if (!obj2.isString()) {
+            error(errSyntaxError, -1, "FormWidgetChoice:: V array contains a non string object");
+            continue;
+          }
+
           bool matches = false;
 
           if (choices[i].exportVal) {
@@ -1933,21 +1938,21 @@ Object Form::fieldLookup(Dict *field, const char *key) {
   return ::fieldLookup(field, key, &usedParents);
 }
 
-FormField *Form::createFieldFromDict (Object &&obj, PDFDoc *docA, const Ref pref, FormField *parent, std::set<int> *usedParents)
+FormField *Form::createFieldFromDict (Object &&obj, PDFDoc *docA, const Ref aref, FormField *parent, std::set<int> *usedParents)
 {
     FormField *field;
 
     const Object obj2 = Form::fieldLookup(obj.getDict (), "FT");
     if (obj2.isName("Btn")) {
-      field = new FormFieldButton(docA, std::move(obj), pref, parent, usedParents);
+      field = new FormFieldButton(docA, std::move(obj), aref, parent, usedParents);
     } else if (obj2.isName("Tx")) {
-      field = new FormFieldText(docA, std::move(obj), pref, parent, usedParents);
+      field = new FormFieldText(docA, std::move(obj), aref, parent, usedParents);
     } else if (obj2.isName("Ch")) {
-      field = new FormFieldChoice(docA, std::move(obj), pref, parent, usedParents);
+      field = new FormFieldChoice(docA, std::move(obj), aref, parent, usedParents);
     } else if (obj2.isName("Sig")) {
-      field = new FormFieldSignature(docA, std::move(obj), pref, parent, usedParents);
+      field = new FormFieldSignature(docA, std::move(obj), aref, parent, usedParents);
     } else { //we don't have an FT entry => non-terminal field
-      field = new FormField(docA, std::move(obj), pref, parent, usedParents);
+      field = new FormField(docA, std::move(obj), aref, parent, usedParents);
     }
 
     return field;
