@@ -6,12 +6,13 @@
    // Copyright (C) 2012 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
    // Copyright (C) 2012, 2017 Adrian Johnson <ajohnson@redneon.com>
    // Copyright (C) 2012 Mark Brand <mabrand@mabrand.nl>
-   // Copyright (C) 2013, 2018 Adam Reichold <adamreichold@myopera.com>
+   // Copyright (C) 2013, 2018, 2019 Adam Reichold <adamreichold@myopera.com>
    // Copyright (C) 2013 Dmytro Morgun <lztoad@gmail.com>
    // Copyright (C) 2017 Christoph Cullmann <cullmann@kde.org>
    // Copyright (C) 2017, 2018 Albert Astals Cid <aacid@kde.org>
    // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
    // Copyright (C) 2019 Christian Persch <chpe@src.gnome.org>
+   // Copyright (C) 2019 Oliver Sander <oliver.sander@tu-dresden.de>
 
 TODO: instead of a fixed mapping defined in displayFontTab, it could
 scan the whole fonts directory, parse TTF files and build font
@@ -27,14 +28,13 @@ description for all fonts available in Windows. That's how MuPDF works.
 #error "_WIN32_IE must be defined >= 0x0500 for SHGFP_TYPE_CURRENT from shlobj.h"
 #endif
 #include <shlobj.h>
-#include <string.h>
-#include <stdio.h>
-#include <ctype.h>
-#include <assert.h>
+#include <cstring>
+#include <cstdio>
+#include <cctype>
+#include <cassert>
 
 #include "goo/gmem.h"
 #include "goo/GooString.h"
-#include "goo/GooList.h"
 #include "goo/gfile.h"
 #include "Error.h"
 #include "NameToCharCode.h"
@@ -389,7 +389,7 @@ static GooString* replaceSuffix(GooString *path,
 }
 
 
-void GlobalParams::setupBaseFonts(char * dir)
+void GlobalParams::setupBaseFonts(const char * dir)
 {
     const char *dataRoot = popplerDataDir ? popplerDataDir : POPPLER_DATADIR;
     GooString *fileName = nullptr;
@@ -447,8 +447,7 @@ void GlobalParams::setupBaseFonts(char * dir)
     if (file != nullptr) {
       Parser *parser;
       parser = new Parser(nullptr,
-	      new Lexer(nullptr,
-	      new FileStream(file, 0, false, file->size(), Object(objNull))),
+              new FileStream(file, 0, false, file->size(), Object(objNull)),
 	      true);
       Object obj1 = parser->getObj();
       while (!obj1.isEOF()) {
@@ -478,7 +477,7 @@ void GlobalParams::setupBaseFonts(char * dir)
     }
 }
 
-static const char *findSubstituteName(GfxFont *font, const std::unordered_map<std::string, std::string>& fontFiles,
+static const char *findSubstituteName(const GfxFont *font, const std::unordered_map<std::string, std::string>& fontFiles,
                                       const std::unordered_map<std::string, std::string>& substFiles,
                                       const char *origName)
 {
@@ -529,11 +528,11 @@ static const char *findSubstituteName(GfxFont *font, const std::unordered_map<st
 }
 
 /* Windows implementation of external font matching code */
-GooString *GlobalParams::findSystemFontFile(GfxFont *font,
+GooString *GlobalParams::findSystemFontFile(const GfxFont *font,
 					  SysFontType *type,
 					  int *fontNum, GooString *substituteFontName,
                                           const GooString *base14Name) {
-  SysFontInfo *fi;
+  const SysFontInfo *fi;
   GooString *path = nullptr;
   const GooString *fontName = font->getName();
   if (!fontName) return nullptr;
