@@ -5,14 +5,13 @@
 // This file is licensed under the GPLv2 or later
 //
 // Copyright 2013 Igalia S.L.
-// Copyright 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright 2018, 2019 Albert Astals Cid <aacid@kde.org>
 //
 //========================================================================
 
 #ifndef MARKEDCONTENTOUTPUTDEV_H
 #define MARKEDCONTENTOUTPUTDEV_H
 
-#include "goo/gtypes.h"
 #include "goo/gmem.h"
 #include "OutputDev.h"
 #include "GfxState.h"
@@ -90,7 +89,7 @@ typedef std::vector<TextSpan> TextSpanArray;
 class MarkedContentOutputDev: public OutputDev {
 public:
   MarkedContentOutputDev(int mcidA);
-  virtual ~MarkedContentOutputDev();
+  ~MarkedContentOutputDev() override;
 
   virtual bool isOk() { return true; }
   bool upsideDown() override { return true; }
@@ -107,7 +106,7 @@ public:
                         double dx, double dy,
                         double ox, double oy,
                         CharCode c, int nBytes,
-                        Unicode *u, int uLen) override;
+                        const Unicode *u, int uLen) override;
 
   void beginMarkedContent(const char *name, Dict *properties) override;
   void endMarkedContent(GfxState *state) override;
