@@ -16,8 +16,9 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
-// Copyright (C) 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2018, 2019 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2019 Volker Krause <vkrause@kde.org>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -28,7 +29,6 @@
 #define UNICODEMAP_H
 
 #include "poppler-config.h"
-#include "goo/gtypes.h"
 #include "CharTypes.h"
 #include <atomic>
 
@@ -46,7 +46,7 @@ typedef int (*UnicodeMapFunc)(Unicode u, char *buf, int bufSize);
 
 struct UnicodeMapRange {
   Unicode start, end;		// range of Unicode chars
-  Guint code, nBytes;		// first output code
+  unsigned int code, nBytes;		// first output code
 };
 
 struct UnicodeMapExt;
@@ -62,7 +62,7 @@ public:
 
   // Create a resident UnicodeMap.
   UnicodeMap(const char *encodingNameA, bool unicodeOutA,
-	     UnicodeMapRange *rangesA, int lenA);
+	     const UnicodeMapRange *rangesA, int lenA);
 
   // Create a resident UnicodeMap that uses a function instead of a
   // list of ranges.
@@ -94,7 +94,7 @@ public:
   // output and returns the number of bytes used.  Output will be
   // truncated at <bufSize> bytes.  No string terminator is written.
   // Returns 0 if no mapping is found.
-  int mapUnicode(Unicode u, char *buf, int bufSize);
+  int mapUnicode(Unicode u, char *buf, int bufSize) const;
 
 private:
 
@@ -104,7 +104,7 @@ private:
   UnicodeMapKind kind;
   bool unicodeOut;
   union {
-    UnicodeMapRange *ranges;	// (user, resident)
+    const UnicodeMapRange *ranges;	// (user, resident)
     UnicodeMapFunc func;	// (func)
   };
   int len;			// (user, resident)
